SimpleWalletBase

Struct SimpleWalletBase 

#[repr(C)]
pub struct SimpleWalletBase;
A simple wallet contract base contract to be used by other contracts.

See the module description for details.

Implementations

Source

impl SimpleWalletBase

pub fn initialize(public_key: &[u8; 32]) -> Result<WalletState, ContractError>

Returns initial state with a provided public key

pub fn authorize( state: &WalletState, header: &TransactionHeader, read_slots: &TxHandlerSlots, write_slots: &TxHandlerSlots, payload: &TxHandlerPayload, seal: &TxHandlerSeal, ) -> Result<(), ContractError>

Reads state of owner and returns Ok(()) if authorization succeeds

pub fn execute( env: &mut Env<'_>, header: &TransactionHeader, read_slots: &TxHandlerSlots, write_slots: &TxHandlerSlots, payload: &TxHandlerPayload, seal: &TxHandlerSeal, ) -> Result<(), ContractError>

Executes provided transactions in the payload.

IMPORTANT:

  • must only be called with trusted input, for example, successful signature verification in SimpleWalletBase::authorize() implies transaction was seen and verified by the user
  • remember to also SimpleWalletBase::increase_nonce() afterward unless there is a very good reason not to (like when wallet was replaced with another implementation containing a different state)

The caller must set themselves as a context or else error will be returned.

pub fn increase_nonce(state: &WalletState) -> Result<WalletState, ContractError>

Returns state with increased nonce

pub fn change_public_key( state: &WalletState, public_key: &[u8; 32], ) -> Result<WalletState, ContractError>

Returns a new state with a changed public key